# Generated by Django 2.2.16 on 2020-10-22 16:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_video_encoder", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="format",
            name="format",
            field=models.CharField(
                choices=[
                    ("H.264 (HD)", "H.264 (HD)"),
                    ("H.264", "H.264"),
                    ("VP9 (HD)", "VP9 (HD)"),
                    ("VP9", "VP9"),
                ],
                max_length=255,
            ),
        ),
    ]
